#include "svg.h"

using namespace std;

void svg_begin(double width, double height)
{
    cout << "<?xml version='1.0' encoding='UTF-8'?>\n"
         << "<svg "
         << "width='" << width << "' "
         << "height='" << height << "' "
         << "viewBox='0 0 " << width << " " << height << "' "
         << "xmlns='http://www.w3.org/2000/svg'>\n";
}
void svg_text(double left, double baseline, string text)
{
    cout << "<text x='" << left << "' y='" << baseline << "'>" << text << "</text>";
}

void svg_rect(double x, double y, double width, double height, const string& stroke, const string& fill)
{
    cout << "<rect x='" << x
         << "' y='" << y
         << "' width='" << width
         << "' height='" << height
         << "' stroke='" << stroke
         << "' fill='" << fill
         << "' />\n";
}

void svg_end()
{
    cout << "</svg>\n";
}
void show_histogram_svg(const vector<size_t>& bins)
{
    const double IMAGE_WIDTH = 400;
    const double IMAGE_HEIGHT = 300;
    const double TEXT_LEFT = 20;
    const double TEXT_BASELINE = 20;
    const double TEXT_WIDTH = 50;
    const double BIN_HEIGHT = 30;
    const double BLOCK_WIDTH = 10;

    svg_begin(IMAGE_WIDTH, IMAGE_HEIGHT);

    size_t max_count = 0;
    for (size_t count : bins)
    {
        if (count > max_count)
        {
            max_count = count;
        }
    }

    double max_width = IMAGE_WIDTH - TEXT_WIDTH;
    double top = 0;
    for (size_t count : bins)
    {
        double bin_width;
        if (max_count > 0)
        {
            bin_width = static_cast<double>(count) / max_count * max_width;
        }
        else
        {
            bin_width = 0.0;
        }

        svg_text(TEXT_LEFT, top + TEXT_BASELINE, to_string(count));
        svg_rect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT, "blue", "#aaffaa");
        top += BIN_HEIGHT;
    }
    svg_end();
}
